require 'minitest/autorun'
require_relative '../../../lib/composers/markov_composer'
require_relative '../../../lib/tweetomator'

class TestMarkovComposer < Minitest::Unit::TestCase
  def setup
    cool_story = "So there I am, in Sri Lanka, formerly Ceylon, at about 3 o'clock in the morning, \nlooking for one thousand brown M&Ms to fill a brandy glass, or Ozzy wouldn't go on stage that night. So, Jeff Beck pops his head 'round the door, \n and mentions there's a little sweets shop on the edge of town. So - we go. And - it's closed. So there's me, and Keith Moon, and David Crosby, breaking into that little sweets shop, eh. Well, instead of a guard dog, they've got this bloody great big Bengal tiger. I managed to take out the tiger with a can of mace, but the shopkeeper and his son... that's a different story altogether. I had to beat them to death with their own shoes. Nasty business, really, but sure enough I got the M&Ms, and Ozzy went on stage and did a great show."
    riveting_tale = "And even in this cosmopolitan trend, he did that precede and open the way to other more advanced civilizations. \n About henceforth in Europe, no cease to be a citizen of his country, it is not, in any way, International? no one  \n can shut, like the snail, by its shell: all need air, space wider for match the new needs, their aspirations."
    @amazing_narrative = "#{cool_story} #{riveting_tale}"
    mock_emoji_finder = Minitest::Mock.new
    mock_emoji_finder.expect :find, 127872.chr('utf-8')
    mock_tweet_finder = Minitest::Mock.new
    mock_tweet_client = Minitest::Mock.new
    @max_length = 100
    @blacklist = %w(sri lanka)
    @stop_words = %w(Potato Salad)
    mock_twitter_config = Minitest::Mock.new
    mock_twitter_config.expect :tweet_max_length, @max_length
    mock_config = Minitest::Mock.new
    mock_config.expect :twitter_config, mock_twitter_config
    mock_config.expect :blacklist, @blacklist
    mock_config.expect :default_hashtag, 'potato'
    mock_config.expect :stop_words, @stop_words
    mock_config.expect :input_text_file, 'text.txt'
    mock_text_reader = MiniTest::Mock.new
    mock_text_reader.expect :process_input_text_file, mock_text_reader
    mock_text_reader.expect :beginnings, @amazing_narrative.split
    mock_text_reader.expect :lines, @amazing_narrative.split("\n")
    TextReader.stub :new, mock_text_reader do
      @markov_composer = MarkovComposer.new(mock_config, mock_tweet_client, mock_tweet_finder, mock_emoji_finder)
    end
  end

  def test_that_tweet_is_short_enough
    tweet = @markov_composer.compose_tweet
    assert tweet.with_hashtags.length <= @max_length, true
  end
end
