require 'minitest/autorun'
require_relative '../../../lib/composers/random_composer'
require_relative '../../../lib/tweetomator'

class TestRandomComposer < Minitest::Unit::TestCase
  def setup
    tweet_1 = 'I just backedeyeyeyey Potato Salad on @Kickstarter kck.st/1pLytCe'
    tweet_2 = 'I HAVE NYANED FOR 48.9 SECONDS! http://nyan.cat  via @nyannyancat'
    cool_story = "So there I am, in Sri Lanka, formerly Ceylon, at about 3 o'clock in the morning, looking for one thousand brown M&Ms to fill a brandy glass, or Ozzy wouldn't go on stage that night. So, Jeff Beck pops his head 'round the door, and mentions there's a little sweets shop on the edge of town. So - we go. And - it's closed. So there's me, and Keith Moon, and David Crosby, breaking into that little sweets shop, eh. Well, instead of a guard dog, they've got this bloody great big Bengal tiger. I managed to take out the tiger with a can of mace, but the shopkeeper and his son... that's a different story altogether. I had to beat them to death with their own shoes. Nasty business, really, but sure enough I got the M&Ms, and Ozzy went on stage and did a great show."
    mock_emoji_finder = Minitest::Mock.new
    mock_emoji_finder.expect :find, 127872.chr('utf-8')
    mock_tweet_finder = Minitest::Mock.new
    mock_tweet_finder.expect :find_tweets, [tweet_1, tweet_2, cool_story]
    mock_tweet_finder.expect :find_tweet, tweet_1, [String]
    mock_tweet_finder.expect :find_random_word, 'amazing', [String]
    mock_tweet_client = Minitest::Mock.new
    @max_length = 100
    @blacklist = %w(sri lanka)
    @stop_words = %w(Potato Salad)
    mock_twitter_config = Minitest::Mock.new
    mock_twitter_config.expect :tweet_max_length, @max_length
    mock_config = Minitest::Mock.new
    mock_config.expect :twitter_config, mock_twitter_config
    mock_config.expect :max_length, @max_length
    mock_config.expect :blacklist, @blacklist
    mock_config.expect :default_hashtag, 'potato'
    mock_config.expect :stop_words, @stop_words
    @random_composer = RandomComposer.new(mock_config, mock_tweet_client, mock_tweet_finder, mock_emoji_finder)
  end

  def test_that_tweet_is_short_enough
    tweet = @random_composer.compose_tweet
    assert tweet.with_hashtags.length <= @max_length, true
  end

  def test_that_blacklisted_words_are_removed
    tweet = @random_composer.compose_tweet
    refute tweet.with_hashtags.split.any? { |word| @blacklist.include?(word) }, true
  end

  def test_that_links_are_removed
    tweet = @random_composer.compose_tweet
    refute tweet.with_hashtags.split.any? { |word| %w(kck.st/1pLytCe http://nyan.cat).include?(word) }, true
  end
end
